@@ -1,10 +1,12 @@
 from typing import Callable, Any, Dict, List
 from concurrent.futures import ThreadPoolExecutor
 
+from .helpers.others import fake
 from .classes.basic_test import Test
 from .classes.basic_case import TestCase
 from .classes.basic_suite import TestSuite
 from .classes.basic_group import TestGroup
+from checking.helpers.report import generate
 from .classes.listeners.basic import Listener
 from .classes.exc_thread import run_with_timeout
 from .classes.listeners.default import DefaultListener
@@ -19,7 +21,7 @@ common_parameters: Dict[str, Any] = {}
 
 def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None, params: Dict[str, Any] = None,
           threads: int = 1, suite_name: str = 'Default Test Suite', dry_run: bool = False, filter_by_name: str = None,
-          **kwargs):
+          random_order: bool = False, generate_report: bool = False, **kwargs):
     """
     The main function of tests start
 
@@ -38,6 +40,8 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
     :param dry_run: if True runs test-suite with fake function except of real tests and fixtures, can be useful to
     find out order, number of tests, params of provider etc.
     :param filter_by_name if specified - runs only tests with name containing this parameter
+    :param random_order if specified - runs tests inside each group in random order
+    :param generate_report if specified - creates html report with the results in test folder
     :return: None
     """
     verbose = 0 if verbose not in range(4) else verbose
@@ -62,7 +66,7 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
         _dry_run(test_suite)
     # Check if all used provider names are found
     _check_data_providers(test_suite)
-    _run(test_suite, threads)
+    _run(test_suite, threads, random_order, generate_report)
 
 
 def _dry_run(test_suite):
@@ -80,10 +84,15 @@ def _dry_run(test_suite):
         for test in group.tests:
             test.before = []
             test.after = []
-            test.test = _fake
+            test.test = fake
 
 
-def _run(test_suite: TestSuite, threads: int = 1):
+def _run(test_suite: TestSuite, threads: int = 1, random_order: bool = False, generate_report: bool = False):
+    for group in test_suite.groups.values():
+        if random_order:
+            group.shuffle_tests()
+        else:
+            group.sort_test_by_priority()
     # Create a pool of threads to run tests, by default 1 thread execution
     pool = ThreadPoolExecutor(max_workers=threads)
     test_suite.start_suite()
@@ -103,6 +112,8 @@ def _run(test_suite: TestSuite, threads: int = 1):
     finally:
         test_suite.stop_suite()
         _listener.on_suite_ends(test_suite)
+        if generate_report:
+            generate(test_suite)
 
 
 def _run_group_before_and_after_at_separate_thread(group: TestGroup):
@@ -151,13 +162,20 @@ def _run_test_with_provider(test):
     :param test: Test
     :return: None
     """
-    generator = _provider_next(test.provider)
+    test_suite = TestSuite.get_instance()
+    provider = test.provider
+    # If provider values is in the cache - get it from there
+    generator = _provider_next(provider) if provider not in test_suite.cache else test_suite.cache[provider]
     try:
         is_any_value_provides = False
+        need_to_cache = provider in test_suite.cached and provider not in test_suite.cache
+        list_of_arguments = []
         for param in generator:
             is_any_value_provides = True
             clone = test.clone()
             clone.argument = param
+            if need_to_cache:
+                list_of_arguments.append(param)
             is_one_of_before_test_failed = _run_test_with_before_and_after(clone, False)
             if is_one_of_before_test_failed:
                 print(f'Because of "before_test" all tests for {test} with data provider '
@@ -167,6 +185,9 @@ def _run_test_with_provider(test):
         if not is_any_value_provides:
             test.stop(TestIgnoredException(f'No values at provider {test.provider}'))
             _listener.on_ignored_with_provider(test)
+        else:
+            if need_to_cache:
+                test_suite.cache[provider] = tuple(list_of_arguments)
     except TypeError as e:
         if 'is not iterable' not in e.args[0]:
             print(e)
@@ -183,7 +204,6 @@ def _run_all_tests_in_group(group: TestGroup):
     :return: None
     """
     is_one_of_before_test_failed = False
-    group.sort_test_by_priority()
     for test in group.tests:
         if test.provider:
             _run_test_with_provider(test)
@@ -314,7 +334,3 @@ def _run_fixture(func: Callable, fixture_type: str, group_name: str) -> bool:
         _listener.on_fixture_failed(group_name, fixture_type, error)
         is_failed = True
     return is_failed
-
-
-def _fake(*args):
-    pass
